aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Target/DarwinTargetAsmInfo.cpp
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2009-07-26 06:48:26 +0000
committerChris Lattner <sabre@nondot.org>2009-07-26 06:48:26 +0000
commit2ceb60a677065e08ec436dcb79a9d445e628a5c9 (patch)
tree70a6d27296a89aa26c8b16e6c5057c3b3fc7fed4 /lib/Target/DarwinTargetAsmInfo.cpp
parent94809c3b108606e287b0966476a381ec907d6c7a (diff)
downloadexternal_llvm-2ceb60a677065e08ec436dcb79a9d445e628a5c9.zip
external_llvm-2ceb60a677065e08ec436dcb79a9d445e628a5c9.tar.gz
external_llvm-2ceb60a677065e08ec436dcb79a9d445e628a5c9.tar.bz2
rename Mergable -> Mergeable and Writable -> Writeable
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@77138 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/DarwinTargetAsmInfo.cpp')
-rw-r--r--lib/Target/DarwinTargetAsmInfo.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/Target/DarwinTargetAsmInfo.cpp b/lib/Target/DarwinTargetAsmInfo.cpp
index 778aa22..503df19 100644
--- a/lib/Target/DarwinTargetAsmInfo.cpp
+++ b/lib/Target/DarwinTargetAsmInfo.cpp
@@ -144,21 +144,21 @@ DarwinTargetAsmInfo::SelectSectionForGlobal(const GlobalValue *GV,
}
// FIXME: Alignment check should be handled by section classifier.
- if (Kind.isMergableCString())
+ if (Kind.isMergeableCString())
return MergeableStringSection(cast<GlobalVariable>(GV));
- if (Kind.isMergableConst()) {
- if (Kind.isMergableConst4())
+ if (Kind.isMergeableConst()) {
+ if (Kind.isMergeableConst4())
return FourByteConstantSection;
- if (Kind.isMergableConst8())
+ if (Kind.isMergeableConst8())
return EightByteConstantSection;
- if (Kind.isMergableConst16() && SixteenByteConstantSection)
+ if (Kind.isMergeableConst16() && SixteenByteConstantSection)
return SixteenByteConstantSection;
return ReadOnlySection; // .const
}
// FIXME: ROData -> const in -static mode that is relocatable but they happen
// by the static linker. Why not mergable?
if (Kind.isReadOnly())
return getReadOnlySection();
@@ -188,17 +188,17 @@ DarwinTargetAsmInfo::MergeableStringSection(const GlobalVariable *GV) const {
}
const Section *
-DarwinTargetAsmInfo::getSectionForMergableConstant(SectionKind Kind) const {
+DarwinTargetAsmInfo::getSectionForMergeableConstant(SectionKind Kind) const {
// If this constant requires a relocation, we have to put it in the data
// segment, not in the text segment.
if (Kind.isDataRel())
return ConstDataSection;
- if (Kind.isMergableConst4())
+ if (Kind.isMergeableConst4())
return FourByteConstantSection;
- if (Kind.isMergableConst8())
+ if (Kind.isMergeableConst8())
return EightByteConstantSection;
- if (Kind.isMergableConst16() && SixteenByteConstantSection)
+ if (Kind.isMergeableConst16() && SixteenByteConstantSection)
return SixteenByteConstantSection;
return ReadOnlySection; // .const
}
@@ -144,21 +144,21 @@ DarwinTargetAsmInfo::SelectSectionForGlobal(const GlobalValue *GV,
}
// FIXME: ROData -> const in -static mode that is relocatable but they happen
- // by the static linker. Why not mergable?
+ // by the static linker. Why not mergeable?
if (Kind.isReadOnly())
return getReadOnlySection();